Learn R Programming

shinyquiz (version 0.0.1)

create_quiz: Create a quiz

Description

Create a single quiz comprising of questions generated from create_question() and/or create_question_raw().

Usage

create_quiz(..., options = set_quiz_options())

Value

an object of class quiz

Arguments

...

objects of class 'quizQuestions'. See create_question(), create_question_raw()

options

a list of options generated from set_quiz_options()

Author

Joseph Marlo

See Also

set_quiz_options(), create_question(), create_question_raw()

Examples

Run this code
quiz <- create_quiz(
  create_question(
    'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Select nulla.',
    add_choice('auctor'),
    add_choice('nulla', correct = TRUE)
  ),
  create_question(
    'Mauris congue aliquet dui, ut dapibus lorem porttitor sed. Select 600.',
    add_choice('600', correct = TRUE),
    add_choice('800')
  )
)

Run the code above in your browser using DataLab