# set the options when creating the quiz
quiz <- create_quiz(
create_question(
'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Select nulla.',
add_choice('auctor'),
add_choice('nulla', correct = TRUE)
),
create_question(
'Mauris congue aliquet dui, ut dapibus lorem porttitor sed. Select 600.',
add_choice('600', correct = TRUE),
add_choice('800')
),
options = set_quiz_options(sandbox = TRUE)
)
# or modify the options on a quiz object
quiz@options <- set_quiz_options(sandbox = FALSE)
# adjust the messages shown at the end of the quiz
messages <- create_messages(
'Congrats!',
'Ahh, bummer! Got at least one wrong',
'Looks like you skipped to the end!'
)
quiz@options <- set_quiz_options(messages = messages)
Run the code above in your browser using DataLab